<?php

namespace Bixo\Offplan\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Bixo\Offplan\Http\Requests\BookingActionsRequest;
use Bixo\Offplan\Actions\BookingActions;

/**
 * Admin web controller class.
 */
class BookingActionsController extends BaseController
{

    /**
     * Action controller function for booking.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(BookingActionsRequest $request, $action)
    {
        try {
            $booking = BookingActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('offplan::booking.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('offplan/booking/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('offplan/booking/' . $action))
                ->redirect();
        }
    }
}
