<?php

namespace Bixo\Offplan\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Offplan\Actions\PaymentAction;
use Bixo\Offplan\Http\Requests\PaymentActionRequest;
use Bixo\Offplan\Http\Resources\PaymentResource;
use Bixo\Offplan\Models\Payment;

/**
 * Admin web controller class.
 */
class PaymentActionController extends BaseController
{

    /**
     * Action controller function for payment.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(PaymentActionRequest $request, Payment $payment, $action)
    {
        try {
            $request = $request->all();
            $payment = PaymentAction::run($action, $payment, $request);

            $data = new PaymentResource($payment);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('offplan::payment.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('offplan/payment/' . $payment->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('offplan/payment/' . $payment->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
