<?php

namespace Bixo\Offplan\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\Offplan\Http\Resources\OffplanResource;
use Bixo\Offplan\Http\Resources\OffplansCollection;
use Bixo\Offplan\Scopes\PaymentPublicScope;
use Bixo\Offplan\Models\Payment;

class PaymentPublicController extends BaseController
{

    /**
     * Show payment's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Payment::pushScope(new RequestScope())
            ->pushScope(new PaymentPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $payments = new PaymentsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('offplan::payment.names'))
            ->view('offplan::public.payment.index')
            ->data(compact('payments', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show payment.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Payment::findBySlug($slug);
        $data = new PaymentResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('offplan::payment.name'))
            ->view('offplan::public.payment.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
