<?php

namespace Bixo\Offplan\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Bixo\Offplan\Forms\Payment as PaymentForm;
use Bixo\Offplan\Http\Requests\PaymentResourceRequest;
use Bixo\Offplan\Http\Resources\PaymentResource;
use Bixo\Offplan\Http\Resources\PaymentsCollection;
use Bixo\Offplan\Models\Payment;
use Bixo\Offplan\Actions\PaymentAction;
use Bixo\Offplan\Actions\PaymentActions;


/**
 * Resource controller class for payment.
 */
class PaymentResourceController extends BaseController
{

    /**
     * Initialize payment resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = PaymentForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('bixo.offplan.modules'), 'offplan', guard_url('offplan'));
            return $next($request);
        });
    }

    /**
     * Display a list of payment.
     *
     * @return Response
     */
    public function index(PaymentResourceRequest $request)
    {
        $request = $request->all();
        $page = PaymentActions::run('paginate', $request);

        $data = new PaymentsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('offplan::payment.names'))
            ->view('offplan::payment.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display payment.
     *
     * @param Request $request
     * @param Model   $payment
     *
     * @return Response
     */
    public function show(PaymentResourceRequest $request, Payment $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new PaymentResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('offplan::payment.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('offplan::payment.show')
            ->output();
    }

    /**
     * Show the form for creating a new payment.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PaymentResourceRequest $request, Payment $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new PaymentResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('offplan::payment.name'))
            ->view('offplan::payment.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new payment.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PaymentResourceRequest $request, Payment $model)
    {
        try {
            $request = $request->all();
            $model = PaymentAction::run('store', $model, $request);
            $data = new PaymentResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('offplan::payment.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('offplan/payment/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/offplan/payment'))
                ->redirect();
        }

    }

    /**
     * Show payment for editing.
     *
     * @param Request $request
     * @param Model   $payment
     *
     * @return Response
     */
    public function edit(PaymentResourceRequest $request, Payment $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new PaymentResource($model);
        // return view('offplan::payment.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('offplan::payment.name'))
            ->view('offplan::payment.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the payment.
     *
     * @param Request $request
     * @param Model   $payment
     *
     * @return Response
     */
    public function update(PaymentResourceRequest $request, Payment $model)
    {
        try {
            $request = $request->all();
            $model = PaymentAction::run('update', $model, $request);
            $data = new PaymentResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('offplan::payment.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('offplan/payment/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('offplan/payment/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the payment.
     *
     * @param Model   $payment
     *
     * @return Response
     */
    public function destroy(PaymentResourceRequest $request, Payment $model)
    {
        try {

            $request = $request->all();
            $model = PaymentAction::run('destroy', $model, $request);
            $data = new PaymentResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('offplan::payment.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('offplan/payment/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('offplan/payment/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
