<?php

namespace Bixo\Offplan\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\Offplan\Http\Resources\OffplanResource;
use Bixo\Offplan\Http\Resources\OffplansCollection;
use Bixo\Offplan\Scopes\ProjectPublicScope;
use Bixo\Offplan\Models\Project;

class ProjectPublicController extends BaseController
{

    /**
     * Show project's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Project::pushScope(new RequestScope())
            ->pushScope(new ProjectPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $projects = new ProjectsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('offplan::project.names'))
            ->view('offplan::public.project.index')
            ->data(compact('projects', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show project.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Project::findBySlug($slug);
        $data = new ProjectResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('offplan::project.name'))
            ->view('offplan::public.project.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
