<?php

namespace Bixo\Offplan\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Offplan\Events\BookingWorkflow as BookingWorkflowEvent;
use Bixo\Offplan\Notifications\BookingWorkflow as BookingWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class BookingWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(BookingWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $booking is submitted.
     *
     * @param BookingWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(BookingWorkflowEvent $event)
    {
        $client = $event->booking->client;
        Notification::send($client, new BookingWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $booking is published.
     *
     * @param BookingWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(BookingWorkflowEvent $event)
    {
        $client = $event->booking->client;
        Notification::send($client, new BookingWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $booking is approved.
     *
     * @param BookingWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(BookingWorkflowEvent $event)
    {
        $client = $event->booking->client;
        Notification::send($client, new BookingWorkflowNotification($event));
    }

    /**
     * Handles the $booking workflow event as a listener.
     *
     * @param BookingWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(BookingWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
