<?php

namespace Bixo\Offplan\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Offplan\Events\FloorplanWorkflow as FloorplanWorkflowEvent;
use Bixo\Offplan\Notifications\FloorplanWorkflow as FloorplanWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class FloorplanWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(FloorplanWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $floorplan is submitted.
     *
     * @param FloorplanWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(FloorplanWorkflowEvent $event)
    {
        $client = $event->floorplan->client;
        Notification::send($client, new FloorplanWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $floorplan is published.
     *
     * @param FloorplanWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(FloorplanWorkflowEvent $event)
    {
        $client = $event->floorplan->client;
        Notification::send($client, new FloorplanWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $floorplan is approved.
     *
     * @param FloorplanWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(FloorplanWorkflowEvent $event)
    {
        $client = $event->floorplan->client;
        Notification::send($client, new FloorplanWorkflowNotification($event));
    }

    /**
     * Handles the $floorplan workflow event as a listener.
     *
     * @param FloorplanWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(FloorplanWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
