<?php
namespace Bixo\Offplan\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Offplan\Events\BookingAction as BookingActionEvent;
use Bixo\Offplan\Models\Booking;

class BookingAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $booking;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param BookingActionEvent $booking
     */
    public function __construct(BookingActionEvent $booking)
    {
        $this->action = $event->action;
        $this->booking = $booking;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Booking Approved - ' . config('app.name'))
            ->view('offplan::booking.email.action', ['data' => $this->booking]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
