<?php
namespace Bixo\Offplan\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Offplan\Events\FloorplanAction as FloorplanActionEvent;
use Bixo\Offplan\Models\Floorplan;

class FloorplanAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $floorplan;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param FloorplanActionEvent $floorplan
     */
    public function __construct(FloorplanActionEvent $floorplan)
    {
        $this->action = $event->action;
        $this->floorplan = $floorplan;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Floorplan Approved - ' . config('app.name'))
            ->view('offplan::floorplan.email.action', ['data' => $this->floorplan]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
