<?php
namespace Bixo\Offplan\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Offplan\Events\UnitAction as UnitActionEvent;
use Bixo\Offplan\Models\Unit;

class UnitAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $unit;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param UnitActionEvent $unit
     */
    public function __construct(UnitActionEvent $unit)
    {
        $this->action = $event->action;
        $this->unit = $unit;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Unit Approved - ' . config('app.name'))
            ->view('offplan::unit.email.action', ['data' => $this->unit]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
