<?php

namespace Bixo\Offplan\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Offplan\Models\Booking;

class BookingPolicy
{

    use BookingAction;
    use BookingExim;
    use BookingReport;
    use BookingWorkflow;

    /**
     * Determine if the given user can view the booking.
     *
     * @param Authenticatable $user
     * @param Booking $booking
     *
     * @return bool
     */
    public function view(Authenticatable $user, Booking $booking)
    {
        if ($authUser->canDo('offplan.booking.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $booking->is_owner;
    }

    /**
     * Determine if the given user can create a booking.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('offplan.booking.create');
    }

    /**
     * Determine if the given user can update the given booking.
     *
     * @param Authenticatable $user
     * @param Booking $booking
     *
     * @return bool
     */
    public function update(Authenticatable $user, Booking $booking)
    {
        if ($user->canDo('offplan.booking.edit') && $user->isAdmin()) {
            return true;
        }

        return $booking->is_owner;
    }

    /**
     * Determine if the given user can delete the given booking.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Booking $booking)
    {
        return $booking->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
