<?php

namespace Bixo\Offplan\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Offplan\Models\Floorplan;

class FloorplanPolicy
{

    use FloorplanAction;
    use FloorplanExim;
    use FloorplanReport;
    use FloorplanWorkflow;

    /**
     * Determine if the given user can view the floorplan.
     *
     * @param Authenticatable $user
     * @param Floorplan $floorplan
     *
     * @return bool
     */
    public function view(Authenticatable $user, Floorplan $floorplan)
    {
        if ($authUser->canDo('offplan.floorplan.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $floorplan->is_owner;
    }

    /**
     * Determine if the given user can create a floorplan.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('offplan.floorplan.create');
    }

    /**
     * Determine if the given user can update the given floorplan.
     *
     * @param Authenticatable $user
     * @param Floorplan $floorplan
     *
     * @return bool
     */
    public function update(Authenticatable $user, Floorplan $floorplan)
    {
        if ($user->canDo('offplan.floorplan.edit') && $user->isAdmin()) {
            return true;
        }

        return $floorplan->is_owner;
    }

    /**
     * Determine if the given user can delete the given floorplan.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Floorplan $floorplan)
    {
        return $floorplan->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
